/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;

import javax.servlet.jsp.JspTagException;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for BreadCrumbException.
 * </p>
 *
 * <p>
 * This class is pretty simple. The test cases simply verifies the exception can be instantiated with the error message
 * and cause properly propagated, and that it comes with correct inheritance.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class BreadCrumbExceptionTests extends TestCase {
    /**
     * <p>
     * The error message used for testing.
     * </p>
     *
     */
    private static final String ERROR_MESSAGE = "test error message";

    /**
     * <p>
     * An exception instance used to create the BreadCrumbException.
     * </p>
     *
     */
    private static final Exception CAUSE_EXCEPTION = new IllegalArgumentException();

    /**
     * <p>
     * Return the test suite of this class.
     * </p>
     *
     * @return the test suite of this class.
     */
    public static Test suite() {
        return new TestSuite(BreadCrumbExceptionTests.class);
    }

    /**
     * <p>
     * Creation test.
     * </p>
     *
     * <p>
     * Verifies the error message is properly propagated.
     * </p>
     */
    public void testBreadCrumbException1() {
        BreadCrumbException bce = new BreadCrumbException(ERROR_MESSAGE);
        assertNotNull("Unable to instantiate BreadCrumbException.", bce);
        assertEquals("Error message is not properly propagated to super class.", ERROR_MESSAGE, bce.getMessage());
    }

    /**
     * <p>
     * Creation test.
     * </p>
     *
     * <p>
     * Verifies the error message and the cause are properly propagated.
     * </p>
     */
    public void testBreadCrumbException2() {
        BreadCrumbException bce = new BreadCrumbException(ERROR_MESSAGE, CAUSE_EXCEPTION);

        assertNotNull("Unable to instantiate BreadCrumbException.", bce);
        assertTrue("The error message should match", bce.getMessage().indexOf(ERROR_MESSAGE) >= 0);
        assertEquals("Cause is not properly propagated to super class.", CAUSE_EXCEPTION, bce.getRootCause());
    }

    /**
     * <p>
     * Inheritance test.
     * </p>
     *
     * <p>
     * Verifies BreadCrumbException subclasses Exception.
     * </p>
     */
    public void testBreadCrumbExceptionInheritance1() {
        BreadCrumbException bce = new BreadCrumbException(ERROR_MESSAGE);
        assertTrue("BreadCrumbException does not subclass Exception.", bce instanceof JspTagException);
    }

    /**
     * <p>
     * Inheritance test.
     * </p>
     *
     * <p>
     * Verifies BreadCrumbException subclasses Exception.
     * </p>
     */
    public void testBreadCrumbExceptionInheritance2() {
        BreadCrumbException bce = new BreadCrumbException(ERROR_MESSAGE, CAUSE_EXCEPTION);
        assertTrue("BreadCrumbException does not subclass Exception.", bce instanceof JspTagException);
    }
}