/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;

import com.topcoder.util.config.ConfigManager;
import com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery.XmlPathDiscovery;

import java.io.File;
import java.util.Map;

/**
 * <p>
 * A helper class to perform those common operations which is helpful for the test.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class TestHelper {
    /**
     * <p>
     * Represents the path of config file for Bread Crumb Trail Tag Component.
     * </p>
     */
    public static final String NAMESPACE = "com.topcoder.web.ui.tag.breadcrumbtrail";

    /**
     * <p>
     * This private constructor prevents to create a new instance.
     * </p>
     */
    private TestHelper() {
    }

    /**
     * <p>
     * Use the given file to config the given namespace the format of the config file is
     * ConfigManager.CONFIG_XML_FORMAT.
     * </p>
     *
     * @param namespace use the namespace to load config information to ConfigManager
     * @param fileName config file to set up environment
     *
     * @throws Exception when any exception occurs
     */
    public static void loadSingleXMLConfig(String namespace, String fileName) throws Exception {
        //set up environment
        ConfigManager config = ConfigManager.getInstance();
        File file = new File(fileName);

        //config namespace
        if (config.existsNamespace(namespace)) {
            config.removeNamespace(namespace);
        }

        config.add(namespace, file.getCanonicalPath(), ConfigManager.CONFIG_XML_FORMAT);
    }

    /**
     * <p>
     * Remove the given namespace in the ConfigManager.
     * </p>
     *
     * @param namespace namespace use to remove the config information in ConfigManager
     *
     * @throws Exception when any exception occurs
     */
    public static void clearConfigFile(String namespace) throws Exception {
        ConfigManager config = ConfigManager.getInstance();

        //clear the environment
        if (config.existsNamespace(namespace)) {
            config.removeNamespace(namespace);
        }
    }

    /**
     * <p>
     * Use the given file to configure the given namespace the format of the configuration file is
     * ConfigManager.CONFIG_MULTIPLE_XML_FORMAT.
     * </p>
     *
     * @param namespace use the namespace to load configuration information to ConfigManager
     * @param fileName configuration file to set up environment
     *
     * @throws Exception when any exception occurs
     */
    public static void loadMultipleXMLConfig(String namespace, String fileName) throws Exception {
        ConfigManager config = ConfigManager.getInstance();
        File file = new File(fileName);

        if (config.existsNamespace(namespace)) {
            config.removeNamespace(namespace);
        }

        config.add(namespace, file.getCanonicalPath(), ConfigManager.CONFIG_MULTIPLE_XML_FORMAT);
    }

    /**
     * <p>
     * Parsing the given xml file and returns the parsed site map.
     * </p>
     *
     * <p>
     * The site map will be a Map with NodeMatcher as the key and a List of NodeMatcher as the value and can
     * be empty. This map represents the NodeMatcher parent to it's children NodeMatcher(s) if any. The list
     * can be empty if there are no children of the parent (i.e. a leaf node).
     * </p>
     *
     * @param file the xml file path
     * @return the site map parsed from the given xml file.
     *
     * @throws Exception to JUnit.
     */
    public static Map getSiteMap(String file) throws Exception {
        XmlPathDiscovery pathDiscovery = new XmlPathDiscovery(file);
        return pathDiscovery.getSiteMap();
    }

    /**
     * <p>
     * Compares two BreadCrumbNode array for equality.
     * </p>
     *
     * @param nodes1 BreadCrumbNode[] to be compared for equality
     * @param nodes2 BreadCrumbNode[] to be compared for equality
     *
     * @return true if two arrays equal, otherwise return false.
     */
    public static boolean isBreadCrumbNodeArrayEquals(BreadCrumbNode[] nodes1, BreadCrumbNode[] nodes2) {
        if (nodes1.length != nodes2.length) {
            return false;
        }

        for (int i = 0; i < nodes1.length; i++) {
            if (!isBreadCrumbNodeEquals(nodes1[i], nodes2[i])) {
                return false;
            }
        }
        return true;
    }

    /**
     * <p>
     * Compares two BreadCrumbNode for equality.
     * </p>
     *
     * @param node1 BreadCrumbNode to be compared for equality
     * @param node2 BreadCrumbNode to be compared for equality
     *
     * @return true if two nodes equal, otherwise return false.
     */
    public static boolean isBreadCrumbNodeEquals(BreadCrumbNode node1, BreadCrumbNode node2) {
        if (node1.getTitle() != null) {
            if (!node1.getTitle().equals(node2.getTitle())) {
                return false;
            }
        } else {
            if (node2.getTitle() != null) {
                return false;
            }
        }

        if (!node1.getUrl().equals(node2.getUrl())) {
            return false;
        }
        return true;
    }

    /**
     * <p>
     * Returns a xml string represents a site map.
     * </p>
     *
     * @return a xml string represents a site map.
     */
    public static String getPathOverride() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("<bc_node title=\"Main\" url=\"/main\" pattern=\"/main\">");
        buffer.append("<bc_node title=\"Help\" url=\"/forums\" pattern=\"/forums[?]id.*\">");
        buffer.append("<bc_node title=\"Topics\" url=\"/topics\" pattern=\"/topics\"/>");
        buffer.append("</bc_node></bc_node>");
        return buffer.toString();
    }

}
