/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.nodediscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;
import com.topcoder.web.ui.tag.breadcrumbtrail.MockHttpServletRequest;
import com.topcoder.web.ui.tag.breadcrumbtrail.MockPageContext;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for HttpServletNodeDiscoveryTag.
 * </p>
 *
 * <p>
 * For in-container tests, please see NodeDiscoveryInContainerTests.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class HttpServletNodeDiscoveryTagTests extends TestCase {
    /**
     * <p>
     * HttpServletNodeDiscoveryTag instance for testing.
     * </p>
     */
    private HttpServletNodeDiscoveryTag tag;

    /**
     * <p>
     * MockPageContext instance for testing.
     * </P>
     */
    private MockPageContext pageContext;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     */
    protected void setUp() {
        pageContext = new MockPageContext();

        tag = new HttpServletNodeDiscoveryTag();
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        tag = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(HttpServletNodeDiscoveryTagTests.class);
    }

    /**
     * <p>
     * Tests ctor HttpServletNodeDiscoveryTag#HttpServletNodeDiscoveryTag() for accuracy.
     * Expects tag is created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new HttpServletNodeDiscoveryTag instance.", tag);
    }

    /**
     * <p>
     * Tests HttpServletNodeDiscoveryTag#getCurrentNode(PageContext) for accuracy.
     * It tests the case when pageContext.getRequest() returns null and expects null current node.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    public void testGetCurrentNode() throws Exception {
        BreadCrumbNode node = tag.getCurrentNode(pageContext);

        assertNull("Expects null BreadCrumbNode returned.", node);
    }

    /**
     * <p>
     * Tests HttpServletNodeDiscoveryTag#getCurrentNode(PageContext) for accuracy.
     * It tests the case when pageContext.getRequest() returns non-null request and expects correct
     * node be returned.
     * </p>
     *
     * <p>
     * Note, the uri and query string is hard-coded in MockHttpServletRequeset class.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    public void testGetCurrentNode2() throws Exception {
        pageContext.setRequest(new MockHttpServletRequest());
        BreadCrumbNode node = tag.getCurrentNode(pageContext);

        assertNotNull("Expects not null BreadCrumbNode returned.", node);
        assertNull("Expects null title.", node.getTitle());
        assertEquals("Failed to get correct url.", "/test/static?id=777", node.getUrl());
    }

    /**
     * <p>
     * Tests HttpServletNodeDiscoveryTag#getCurrentNode(PageContext) for failure.
     * It tests the case that when pageContext is null and expects IllegalArgumentException.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    public void testGetCurrentNode_NullPageContext() throws Exception {
        try {
            tag.getCurrentNode(null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

}