/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for AbstractNodeMatcher.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class AbstractNodeMatcherTests extends TestCase {
    /**
     * <p>
     * Title string for creating new AbstractNodeMatcher instance.
     * </p>
     */
    private static final String TITLE = "TOPCODER";

    /**
     * <p>
     * URL String for creating new AbstractNodeMatcher instance.
     * </p>
     */
    private static final String URL = "http://www.topcoder.com";

    /**
     * <p>
     * AbstractNodeMatcher instance for testing.
     * </p>
     */
    private AbstractNodeMatcher nodeMatcher;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     */
    protected void setUp() {
        nodeMatcher = new SimpleNodeMatcher(TITLE, URL);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        nodeMatcher = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(AbstractNodeMatcherTests.class);
    }

    /**
     * <p>
     * Tests ctor AbstractNodeMatcher#AbstractNodeMatcher(String,String) for accuracy.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new AbstractNodeMatcher instance.", nodeMatcher);
    }

    /**
     * <p>
     * Tests ctor AbstractNodeMatcher#AbstractNodeMatcher(String,String) for failure.
     * It tests the case that when title is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_NullTitle() {
        try {
            new SimpleNodeMatcher(null, URL);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor AbstractNodeMatcher#AbstractNodeMatcher(String,String) for failure.
     * It tests the case that when title is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_EmptyTitle() {
        try {
            new SimpleNodeMatcher(" ", URL);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor AbstractNodeMatcher#AbstractNodeMatcher(String,String) for failure.
     * It tests the case that when url is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_NullUrl() {
        try {
            new SimpleNodeMatcher(TITLE, null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor AbstractNodeMatcher#AbstractNodeMatcher(String,String) for failure.
     * It tests the case that when url is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_EmptyUrl() {
        try {
            new SimpleNodeMatcher(TITLE, "  ");
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests AbstractNodeMatcher#getTitle() for accuracy.
     * Expects title is correctly set in constructor.
     * </p>
     */
    public void testGetTitle() {
        assertEquals("Failed to get correct title.", TITLE, nodeMatcher.getTitle());
    }

    /**
     * <p>
     * Tests AbstractNodeMatcher#getUrl() for accuracy.
     * Expects url is correctly set in constructor.
     * </p>
     */
    public void testGetUrl() {
        assertEquals("Failed to get correct url.", URL, nodeMatcher.getUrl());
    }

    /**
     * <p>
     * This class extends AbstractNodeMatcher class.
     * It is used for testing propose.
     * </p>
     *
     * @author TCSDEVELOPER
     * @version 2.0
     */
    private static final class SimpleNodeMatcher extends AbstractNodeMatcher {
        /**
         * <p>
         * Constructs a new SimpleNodeMatcher instance.
         * It simply call the super corresponding constructor.
         * </p>
         *
         * @param title A non-null, non-empty (trim'd) title to use
         * @param url A non-null, non-empty (trim'd) url to use
         *
         * @throws IllegalArgumentException if either arg is an empty (trim'd) string
         */
        protected SimpleNodeMatcher(String title, String url) {
            super(title, url);
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         *
         * @param node node.
         *
         * @return false forever.
         */
        public boolean matches(BreadCrumbNode node) {
            return false;
        }
    }

}