/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;
import com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery.nodematchers.RegexNodeMatcher;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for NodePair.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class NodePairTests extends TestCase {
    /**
     * <p>
     * BreadCrumbNode instance for creating NodePair instance.
     * </p>
     */
    private BreadCrumbNode node;

    /**
     * <p>
     * RegexNodeMatcher instance for creating NodePair instance.
     * </p>
     */
    private RegexNodeMatcher nodeMatcher;

    /**
     * <p>
     * NodePair instance for testing.
     * </p>
     */
    private NodePair nodePair;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     * @throws Exception to JUnit
     */
    protected void setUp() throws Exception {
        String url = "http://www.topcoder.com";
        node = new BreadCrumbNode(url, "main");
        nodeMatcher = new RegexNodeMatcher("topcoder", url, "http://www.topcoder.com/.*");

        nodePair = new NodePair(node, nodeMatcher);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        node = null;
        nodeMatcher = null;
        nodePair = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(NodePairTests.class);
    }

    /**
     * <p>
     * Tests ctor NodePair#NodePair(BreadCrumbNode,NodeMatcher) for accuracy.
     * Expects nodePair is successfully created.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create a new NodePair instance.", nodePair);
    }

    /**
     * <p>
     * Tests ctor NodePair#NodePair(BreadCrumbNode,NodeMatcher) for failure.
     * It tests the case that when node is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_NullNode() {
        try {
            new NodePair(null, nodeMatcher);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor NodePair#NodePair(BreadCrumbNode,NodeMatcher) for accuracy.
     * It tests the case that when nodeMatcher is null and expects success.
     * </p>
     */
    public void testCtor_NullNodeMatcher() {
        assertNotNull("Failed to create a new NodePair instance when nodeMatcher is null.", new NodePair(node, null));
    }

    /**
     * <p>
     * Tests NodePair#getNode() for accuracy.
     * It tests the case when the title of the node is non-null and expects the original node is returned.
     * </p>
     */
    public void testGetNode() {
        assertEquals("Failed to get correct title.", node.getTitle(), nodePair.getNode().getTitle());
        assertEquals("Failed to get correct url.", node.getUrl(), nodePair.getNode().getUrl());
    }

    /**
     * <p>
     * Tests NodePair#getNode() for accuracy.
     * It tests the case when the title of the node is null and nodeMathcer is non-null.
     * Expects a new node with the title in nodeMatcher and the url in node is returned.
     * </p>
     */
    public void testGetNode2() {
        node = new BreadCrumbNode("http://www.topcoder.com", null);

        nodePair = new NodePair(node, nodeMatcher);

        assertEquals("Failed to get correct title.", nodeMatcher.getTitle(), nodePair.getNode().getTitle());
        assertEquals("Failed to get correct url.", node.getUrl(), nodePair.getNode().getUrl());
    }

    /**
     * <p>
     * Tests NodePair#getNode() for accuracy.
     * It tests the case when the title of the node is null and nodeMathcer is null.
     * Expects the original node is returned.
     * </p>
     */
    public void testGetNode3() {
        node = new BreadCrumbNode("http://www.topcoder.com", null);

        nodePair = new NodePair(node, null);

        assertEquals("Failed to get correct title.", node.getTitle(), nodePair.getNode().getTitle());
        assertEquals("Failed to get correct url.", node.getUrl(), nodePair.getNode().getUrl());
    }

    /**
     * <p>
     * Tests NodePair#getNodeMatcher() for accuracy.
     * Expects nodeMathcer instance is correctly set.
     * </p>
     */
    public void testGetNodeMatcher() {
        assertTrue("Expects the nodeMatcher is of RegexNodeMathcer type.",
                nodePair.getNodeMatcher() instanceof RegexNodeMatcher);

        RegexNodeMatcher actualNodeMatcher = (RegexNodeMatcher) nodePair.getNodeMatcher();

        assertEquals("Failed to get correct title.", nodeMatcher.getTitle(), actualNodeMatcher.getTitle());
        assertEquals("Failed to get correct url.", nodeMatcher.getUrl(), actualNodeMatcher.getUrl());
        assertEquals("Failed to get correct node pattern.", nodeMatcher.getNodePattern(),
                actualNodeMatcher.getNodePattern());
    }

}